toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'MarketModel{open: $open, high: $high, low: $low, close: $close, vol: $vol, time: $time, amount: $amount, ratio: $ratio, change: $change, mac_high: $mac_high, mac_upper: $mac_upper, mac_low: $mac_low, mac_lower: $mac_lower, mac_high_1: $mac_high_1, mac_upper_1: $mac_upper_1, mac_low_1: $mac_low_1, mac_lower_1: $mac_lower_1, rsi: $rsi, rsi_signal: $rsi_signal, rsi_flag: $rsi_flag, stochastic_kd_flag: $stochastic_kd_flag, moving_average: $moving_average, top_box: $top_box, bottom_box: $bottom_box}';
}